@@ -27,9 +27,6 @@ class IWPloneProject(templates.Template):
     summary = 'Plone 3 buildout files for Ingeniweb projects'
     use_cheetah = True
 
-    vars = [var('zope_user', 'Zope root admin user', default='admin'),
-            var('zope_password', 'Zope root admin password'),
-            var('http_port', 'HTTP port', default=8080),
-            var('debug_mode', 'Should debug mode be "on" or "off"?', default='off'),
-            var('verbose_security', 'Should verbose security be "on" or "off"?', default='off')]
+    vars = [var('project_name', 'Project name', default='Ingeniweb Project')]
+
 
